# قیمت لحظه‌ای دلار و پوند و تبدیل به ریال | Gheymat

کتابخانه‌ای برای دریافت قیمت دلار و پوند به صورت لحظه‌ای و تبدیل آن به ریال.

  
## نصب

```bash
pip install gheymat
```
## استفاده
```python
from gheymat.currency import USD #or GBP

dollar_price = USD()
print(dollar_price)
```
